.. include:: ../README.rst
   :start-after: include-section-overview-start
   :end-before: include-section-overview-end

========
Contents
========

.. toctree::
   :maxdepth: 2

   usage
   reference/index
   contributing
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

